<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class crm20000ApropriaController extends TeknisaCrud
{
    protected $dataSourceName = 'crm_apropriacontato';

    protected $entityManager;
    protected $connection;
    protected $newCode;

    public function __construct ($crudService, $parameterBag, $entityManager, $newCode)
    {
        $this->parameterBag  = $parameterBag;
        $this->entityManager = $entityManager;
        $this->newCode       = $newCode;
        $this->connection    = $entityManager->getConnection();

        parent::__construct($crudService, $parameterBag);
    }

    public function save(DTO\Request $request, DTO\Response $response)
    {
        foreach($request->getDataSet()->getRows() as $row)
        {
            if (!array_key_exists('DTULTATU', $row)) $row['DTULTATU'] = null;
            if (!array_key_exists('IDATIVO', $row)) $row['IDATIVO'] = 'S';

            if ($row['__is_new'] && (!isset($row['NRSEQAPONTAMENTO'])))
            {
                $row['NRSEQAPONTAMENTO'] = $this->newCode->getCodeByTableName("CRM_APONTAMENTO", $row["NRORG"]);

                date_default_timezone_set('America/Sao_Paulo');
                $row['DTINCLUSAO'] = date('d/m/y');

                $nrseqrelacapont = $this->newCode->getCodeByTableName("CRM_RELACEVOLAPONT", $row["NRORG"]);

                $response->addDataSet(new DataSet("DADOS", array("NRSEQAPONTAMENTO" => $row["NRSEQAPONTAMENTO"], "NRSEQRELACAPONT" => $nrseqrelacapont, "DTINCLUSAO" => $row["DTINCLUSAO"])));
                parent::save($request, $response);

                $this->insertRelacevolapont($row, $nrseqrelacapont);
            }
            else
            {
                date_default_timezone_set('America/Sao_Paulo');
                $row['DTULTATU'] = date('d/m/y');
                $response->addDataSet(new DataSet("DADOS", array("DTULTATU" => $row["DTULTATU"])));
                parent::save($request, $response);
            }
        }
    }

    public function insertRelacevolapont($row, $nrseqrelacapont)
    {
        $insert = "INSERT INTO CRM_RELACEVOLAPONT
                               (NRSEQRELACAPONT, NRSEQAPONTAMENTO, NRSEQEVOLCONT, NRORG, DTULTATU,
                                NRORGINCLUSAO, DTINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU)
                        VALUES (:NRSEQRELACAPONT, :NRSEQAPONTAMENTO, :NRSEQEVOLCONT, :NRORG, :DTULTATU, :NRORGINCLUSAO, :DTINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU)";

        $params = array
        (
            'NRSEQRELACAPONT'  => $nrseqrelacapont,
            'NRSEQAPONTAMENTO' => $row["NRSEQAPONTAMENTO"],
            'NRSEQEVOLCONT'    => $row["NRSEQEVOLCONT"],
            'NRORG'            => $row["NRORG"],
            'DTULTATU'         => null,
            'NRORGINCLUSAO'    => $row["NRORG"],
            'DTINCLUSAO'       => $row["DTINCLUSAO"],
            'CDOPERINCLUSAO'   => $row["CDOPERINCLUSAO"],
            'NRORGULTATU'      => null,
            'CDOPERULTATU'     => null
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
            return $nrseqrelacapont;
        }
        catch(\Exception $e)
        {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
            return NULL;
        };
    }

    public function remove($request, DTO\Response $response)
    {
        $row = $request->getRow();
        $this->deleteRelacevolapont($row);

        parent::remove($request, $response);
    }

    public function deleteRelacevolapont($row)
    {
        $delete = "DELETE FROM CRM_RELACEVOLAPONT
                         WHERE NRSEQRELACAPONT  = :NRSEQRELACAPONT
                           AND NRSEQAPONTAMENTO = :NRSEQAPONTAMENTO
                           AND NRSEQEVOLCONT    = :NRSEQEVOLCONT
                           AND NRORG            = :NRORG";
        $params = array
        (
            "NRSEQRELACAPONT"  => $row["NRSEQRELACAPONT"],
            "NRSEQAPONTAMENTO" => $row["NRSEQAPONTAMENTO"],
            "NRSEQEVOLCONT"    => $row["NRSEQEVOLCONT"],
            "NRORG"            => $row["NRORG"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($delete);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        };
    }

}