<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\Model\Util\NovoCodigo;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Filter;

class ger00100OperadorController extends TeknisaCrud
{
    protected $dataSourceName = 'operadorTelaPrincipal';

    protected $entityManager;
    protected $connection;
    protected $newCode;
    
    protected $parameterBagColumns = array('P_IDOPERMASTER', 'OPERADOR_LOGADO', 'NRORG');

    public function __construct ($crudService, $parameterBag, $entityManager, $newCode)
    {
        $this->entityManager = $entityManager;
         $this->newCode      = $newCode;
        $this->connection    = $entityManager->getConnection();

        parent::__construct($crudService, $parameterBag);
    }
    
    public function findCliente(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = 'cliente';
        $this->parameterBagColumns = array();
        parent::find($request, $response);
    }
    
    public function findEstruturam(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = 'estruturam';
        $this->parameterBagColumns = array();
        parent::find($request, $response);
    }

    public function save(DTO\Request $request, DTO\Response $response)
    {
        foreach($request->getDataSet()->getRows() as $row)
        {
            $this->connection->beginTransaction();
            try
            {
                if($row['__is_new'])
                {
                    if($row['CDOPERADOR'] == null)
                    {
                        $row['CDOPERADOR'] = self::getMaxOperCode($row);
                    }
                    
                    $row['CDOPERADOR'] = str_pad("".$row['CDOPERADOR']."", 12, "0", STR_PAD_LEFT);
                    //$row["CDSENHOPER"] = self::_retornaSenhaCriptografada($row["CDSENHAOPERWEB"]);
                    $row["CDSENHAOPERWEB"] = md5($row["CDSENHAOPERWEB"]);

                    //Se não tiver sido selecionado parceiro, cria um novo seta o selecionado na row
                    if(empty($row['NRPARCNEGOCIO'])){
                        $row['NRPARCNEGOCIO'] = NovoCodigo::geraCodigo($row["NRORG"], "PARCNEGOCIO", 1, 10, false, false);
                        self::criaParcnegocio($row);
                        self::criaParceria($row, "OPERADOR");
                    }
                    
                    if($row["CDCLIENTE"] != null)
                    {
                        $row["NRRELACIONAPARC"] = NovoCodigo::geraCodigo($row["NRORG"], "RELACPARCNEG", 1, 10, false, false);
                        self::criaParceria($row, "INTERLOCUTOR");
                        self::criaRelacionaParc($row);
                        self::criaInteclie($row);
                    }
                    
                    parent::save($request, $response);
                    self::criaOrganOper($row);
                    if(isset($row["FILIAIS"])){
                        foreach ($row["FILIAIS"] as $filial) {
                            $row["CDFILIAL"] = $filial;
                            self::replicaFiliais($row);
                        }
                    }

                    $response->addDataSet(new DataSet("DADOS", array("CDOPERADOR" => $row["CDOPERADOR"], "NRPARCNEGOCIO" => $row["NRPARCNEGOCIO"], "CDSENHAOPERWEB" => $row["CDSENHAOPERWEB"])));
                }
                else
                {
                    
                    if(($row["OLDNRINSCRICAOPARC"] != $row["NRINSCRICAOPARC"]) || ($row["OLDNMOPERADOR"] != $row["NMOPERADOR"]))
                    {
                        self::updataParcnegocio($row);
                    }

                    if($row["CDCLIENTE"] != $row["OLDCDCLIENTE"])
                    {
                        self::validarUpdateCliente($row);
                    }

                    if($row["OLDCDSENHAOPERWEB"] != $row["CDSENHAOPERWEB"])
                    {
                        //$row["CDSENHOPER"] = self::_retornaSenhaCriptografada($row["CDSENHAOPERWEB"]);
                        $row["CDSENHAOPERWEB"] = md5($row["CDSENHAOPERWEB"]);
                    }

                    //Se não tiver sido selecionado parceiro, cria um novo seta o selecionado na row
                    if(empty($row['NRPARCNEGOCIO'])){
                        $row['NRPARCNEGOCIO'] =  NovoCodigo::geraCodigo($row["NRORG"], "PARCNEGOCIO", 1, 10, false, false);
                        self::criaParcnegocio($row);
                        self::criaParceria($row, "OPERADOR");
                    }
                    
                    $response->addDataSet(new DataSet("DADOS", array("CDSENHAOPERWEB" => $row["CDSENHAOPERWEB"])));
                    parent::save($request, $response);
                }
                $this->connection->commit();
            }catch(\Exception $e)
            {
                
                $this->connection->rollBack();
                $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
            }
        }
    }
    
    public function saveSenha(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $row["CDSENHAOPERWEB"] = md5($row["CDSENHAOPERWEB"]);
        $response->addDataSet(new DataSet("DADOS", array("CDSENHAOPERWEB" => $row["CDSENHAOPERWEB"])));
        parent::save($request, $response);
        
    }

    public function deleteOrg(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = 'crm_organOper';
        $this->parameterBagColumns = array();
        parent::delete($request, $response);   
    }
    
    public function _retornaSenhaCriptografada($senha)
    {
        // verificar se o servidor permite o acesso a esta url
        $url = 'https://www.security.teknisa.com/comwebservice/service.asmx?wsdl';

        $opcoes = array
        (
            'encoding'    => 'ISO-8859-1',
            'trace'       => true,
            'exceptions'  => true,
            'compression' => SOAP_COMPRESSION_ACCEPT | SOAP_COMPRESSION_GZIP,
        );

        $argumentos = array
        (
            new \SoapVar(utf8_decode($senha), XSD_STRING, 'string', "http://www.w3.org/2001/XMLSchema")
        );

        $parametros = array
        (
            'rdm'    => 'Bib_Html.rdmDBGeralHtm',
            'method' => 'GetCriptoPass',
            'args'   => $argumentos,
        );

        try
        {
            $client = new \SoapClient($url, $opcoes);
            $retorno = $client->executeCOMMethod($parametros);
            $cryptoPassword = $retorno->executeCOMMethodResult;
        }catch(\SoapFault $e)
        {
            throw new \Exception($e->getMessage());
        }

        return $cryptoPassword;
    }
    
    public function getMaxOperCode($row){
        $select = "SELECT LPAD(TO_CHAR(MAX(TO_NUMBER(DECODE(REPLACE(TRANSLATE(CDOPERADOR, '0123456789', '##########'), '#', ''), NULL, CDOPERADOR, NULL)))+1), 12, '0') MAX_ID FROM OPERADOR WHERE NRORG =:NRORG";
        $params = array('NRORG' => $row['NRORG'] );
        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $result = $std->fetchAll();
            return $result[0]["MAX_ID"]+10;
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function criaParcnegocio($row)
    {
        $insert = "INSERT INTO PARCNEGOCIO
                              (NRPARCNEGOCIO, NRORG, NMPRINCIPALPARC, NMSECUNDARIPARC, NRINSCRICAOPARC, IDATIVO,
                               DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, CDTIPOPARCPRINCIPAL, CDTIPOINSCRICAO,
                               IDPESSOAFISICA, IDINSTITUICAO, IDPARCFUNDIDO)
                       VALUES (:NRPARCNEGOCIO, :NRORG, :NMOPERADOR, :NMOPERADOR, :NRINSCRICAOPARC, :IDATIVO,
                                SYSDATE, :NRORG, :CDOPERINCLUSAO, :CDTIPOPARCPRINCIPAL, :CDTIPOINSCRICAO,
                               :IDPESSOAFISICA, :IDINSTITUICAO, :IDPARCFUNDIDO)";

        $params = array
        (
            "NRPARCNEGOCIO"       => $row["NRPARCNEGOCIO"],
            "NRORG"               => $row["NRORG"],
            "NMOPERADOR"          => $row["NMOPERADOR"],
            "NRINSCRICAOPARC"     => $row["NRINSCRICAOPARC"],
            "IDATIVO"             => 'S',
            "CDOPERINCLUSAO"      => $row["CDOPERINCLUSAO"],
            "CDTIPOPARCPRINCIPAL" => "OPERADOR",
            "CDTIPOINSCRICAO"     => $row["CDTIPOINSCRICAO"],
            "IDPESSOAFISICA"      =>  'S',
            "IDINSTITUICAO"       => 'N',
            "IDPARCFUNDIDO"       => 'N'
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function updataParcnegocio($row)
    {
        $update = "UPDATE PARCNEGOCIO
                      SET NRINSCRICAOPARC = :NRINSCRICAOPARC,
                          CDTIPOINSCRICAO = :CDTIPOINSCRICAO,
                          NMPRINCIPALPARC = :NMOPERADOR,
                          NMSECUNDARIPARC = :NMOPERADOR,
                          DTULTATU        = SYSDATE,
                          NRORGULTATU     = :NRORGULTATU,
                          CDOPERULTATU    = :CDOPERULTATU
                    WHERE NRPARCNEGOCIO   = :NRPARCNEGOCIO
                      AND NRORG           = :NRORG";

        $params = array
        (
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "NRORG"           => $row["NRORG"],
            "NMOPERADOR"      => $row["NMOPERADOR"],
            "NRINSCRICAOPARC" => $row["NRINSCRICAOPARC"],
            "CDOPERULTATU"    => $row["CDOPERULTATU"],
            "CDTIPOINSCRICAO" => $row["CDTIPOINSCRICAO"],
            "NRORGULTATU"     => $row["NRORGULTATU"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function criaParceria($row, $cdtipoparceiro)
    {
        $insert = "INSERT INTO PARCERIA
                              (NRPARCERIA, NRPARCNEGOCIO, CDTIPOPARCEIRO, NRORG, IDATIVO,
                               DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                       VALUES (:NRPARCERIA, :NRPARCNEGOCIO, :CDTIPOPARCEIRO, :NRORG, :IDATIVO,
                                SYSDATE, :NRORG, :CDOPERINCLUSAO)";

        $params = array
        (
            "NRPARCERIA"     => NovoCodigo::geraCodigo($row["NRORG"], "PARCERIA", 1, 10, false, false),
            "NRPARCNEGOCIO"  => $row["NRPARCNEGOCIO"],
            "NRORG"          => $row["NRORG"],
            "CDTIPOPARCEIRO" => $cdtipoparceiro,
            "IDATIVO"        => 'S',
            "CDOPERINCLUSAO" => $row["CDOPERINCLUSAO"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
        }catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function criaOrganOper($row)
    {
        $insert = "INSERT INTO ORGANIZACAOOPER
                              (NRORGANIZACAOOPER, NRORGREL, CDOPERADOR, DTINCLUSAO, NRORGINCLUSAO,
                               CDOPERINCLUSAO, NRORG, IDATIVO)
                       VALUES (:NRORGANIZACAOOPER, :NRORGTRAB, :CDOPERADOR, SYSDATE, :NRORG,
                               :CDOPERINCLUSAO, :NRORG, :IDATIVO)";

        $params = array
        (
            "NRORGANIZACAOOPER" => NovoCodigo::geraCodigo($row["NRORG"], "ORGANIZACAOOPER", 1, 4, false, false),
            "NRORGTRAB"         => $row["NRORGTRAB"],
            "CDOPERADOR"        => $row["CDOPERADOR"],
            "CDOPERINCLUSAO"    => $row["CDOPERINCLUSAO"],
            "NRORG"             => $row["NRORG"],
            "IDATIVO"           => 'S'
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
        }catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function criaRelacionaParc($row)
    {
        $insert = "INSERT INTO RELACIONAPARC
                              (NRRELACIONAPARC, NRORG, NRPARCNEGOCIO, NRPARCNEGRELAC, NRTIPORELACIONA,
                               IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                        SELECT :NRRELACIONAPARC AS NRRELACIONAPARC, :NRORG AS NRORG, NRPARCNEGOCIO,
                               :NRPARCNEGOCIO AS NRPARCNEGRELAC, :NRTIPORELACIONA AS NRTIPORELACIONA,
                               :IDATIVO AS IDATIVO, SYSDATE AS DTINCLUSAO, :NRORG AS NRORGINCLUSAO,
                               :CDOPERINCLUSAO AS CDOPERINCLUSAO
                          FROM CLIENTE
                         WHERE CDCLIENTE = :CDCLIENTE
                           AND NRORG     = :NRORG";

        $params = array
        (
            "NRRELACIONAPARC" => $row["NRRELACIONAPARC"],
            "NRORG"           => $row["NRORG"],
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "NRTIPORELACIONA" => 25,
            "IDATIVO"         => 'S',
            "CDOPERINCLUSAO"  => $row["CDOPERINCLUSAO"],
            "CDCLIENTE"        => $row["CDCLIENTE"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
        }catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function criaInteclie($row)
    {
        $insert = "INSERT INTO INTECLIE
                              (CDCLIENTE, CDINTECLIE, NMINTECLIE, CDPAIS, NRORG, DTINCLUSAO,
                               NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO, NRRELACIONAPARC)
                       VALUES (:CDCLIENTE, :CDINTECLIE, :NMOPERADOR, :CDPAIS, :NRORG, SYSDATE,
                               :NRORG, :CDOPERINCLUSAO, :IDATIVO, :NRRELACIONAPARC)";

        $params = array
        (
            "CDCLIENTE"       => $row["CDCLIENTE"],
            "CDINTECLIE"      => NovoCodigo::geraCodigo($row["NRORG"], 'INTECLIE'.$row["CDCLIENTE"], 1, 2, false, false),
            "NMOPERADOR"      => $row["NMOPERADOR"],
            "CDPAIS"          => $row["CDPAIS"],
            "NRORG"           => $row["NRORG"],
            "CDOPERINCLUSAO"  => $row["CDOPERINCLUSAO"],
            "IDATIVO"         => 'S',
            "NRRELACIONAPARC" => $row["NRRELACIONAPARC"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
        }catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function getOrganizacao(Row $row, Response $response)
    {
        $row = $row->getRow();

        $select = "SELECT NMORGANIZACAO
                     FROM ORGANIZACAO
                    WHERE NRORG = :NRORG";

        $params = array
        (
            "NRORG" => $row["NRORG"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $result = $std->fetchAll();
            $response->addDataSet(new DataSet("DADOS", array("NMORGANIZACAO" => $result[0]["NMORGANIZACAO"])));
        }
        catch(\Exception $e)
        {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        };
    }


    public function existeCdoperador(Row $row, Response $response)
    {
        $row = $row->getRow();

        $select = "SELECT COUNT(*) AS COUNT
                     FROM OPERADOR
                    WHERE CDOPERADOR = :CDOPERADOR
                      AND NRORG      = :NRORG";

        $params = array
        (
            "NRORG"      => $row["NRORG"],
            "CDOPERADOR" => $row["CDOPERADOR"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $result = $std->fetchAll();

            $response->addDataSet(new DataSet("DADOS", array("EXISTE" => ($result[0]["COUNT"] > 0))));
        }
        catch(\Exception $e)
        {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        };
    }

    public function validarUpdateCliente($row)
    {
        if($row["CDCLIENTE"] == null)
        {
            self::inativaTodosRelacParc($row);
            self::inativaTodosInteClie($row);
            self::setParceriaAtivaInativa($row, "N");
        }else
        {
            if(self::existeParceriaInterlocutor($row) == 0)
            {
                self::criaParceria($row, "INTERLOCUTOR");
            }
            else
            {
                self::setParceriaAtivaInativa($row, "S");
            }

            self::inativaTodosRelacParc($row);
            if(self::existeRelacParc($row) > 0)
            {
                self::ativaRelacParc($row);
            }
            else
            {
                $row["NRRELACIONAPARC"] = NovoCodigo::geraCodigo($row["NRORG"], 'RELACPARCNEG', 1, 10, false, false);
                self::criaRelacionaParc($row);
            }

            self::inativaTodosInteClie($row);
            if(self::existeInteClie($row) > 0)
            {
                self::ativaInteClie($row);
            }
            else
            {
                self::criaInteclie($row);
            }
        }
    }

    public function inativaTodosRelacParc($row)
    {
        $update = "UPDATE RELACIONAPARC
                      SET IDATIVO         = :IDATIVO,
                          CDOPERULTATU    = :CDOPERULTATU,
                          NRORGULTATU     = :NRORGULTATU,
                          DTULTATU        = SYSDATE
                    WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                      AND NRORG           = :NRORG
                      AND NRTIPORELACIONA = :NRTIPORELACIONA";

        $params = array
        (
            "NRORG"           => $row["NRORG"],
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "NRORGULTATU"     => $row["NRORGULTATU"],
            "CDOPERULTATU"    => $row["CDOPERULTATU"],
            "IDATIVO"         => "N",
            "NRTIPORELACIONA" => 25
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function inativaTodosInteClie($row)
    {
        $update = "UPDATE INTECLIE
                      SET IDATIVO         = :IDATIVO,
                          CDOPERULTATU    = :CDOPERULTATU,
                          NRORGULTATU     = :NRORGULTATU,
                          DTULTATU        = SYSDATE
                    WHERE NRRELACIONAPARC IN
                          (SELECT NRRELACIONAPARC
                             FROM RELACIONAPARC
                            WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                              AND NRORG           = :NRORG
                              AND NRTIPORELACIONA = :NRTIPORELACIONA)
                      AND NRORG           = :NRORG";

        $params = array
        (
            "NRORG"           => $row["NRORG"],
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "NRORGULTATU"     => $row["NRORGULTATU"],
            "CDOPERULTATU"    => $row["CDOPERULTATU"],
            "IDATIVO"         => "N",
            "NRTIPORELACIONA" => 25
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function setParceriaAtivaInativa($row, $idativo)
    {
        $update = "UPDATE PARCERIA
                      SET IDATIVO        = :IDATIVO,
                          CDOPERULTATU   = :CDOPERULTATU,
                          NRORGULTATU    = :NRORGULTATU,
                          DTULTATU       = SYSDATE
                    WHERE NRPARCNEGOCIO  = :NRPARCNEGOCIO
                      AND NRORG          = :NRORG
                      AND CDTIPOPARCEIRO = :CDTIPOPARCEIRO";

        $params = array
        (
            "NRORG"          => $row["NRORG"],
            "NRPARCNEGOCIO"  => $row["NRPARCNEGOCIO"],
            "NRORGULTATU"    => $row["NRORGULTATU"],
            "CDOPERULTATU"   => $row["CDOPERULTATU"],
            "IDATIVO"        => $idativo,
            "CDTIPOPARCEIRO" => "INTERLOCUTOR"
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function existeParceriaInterlocutor($row)
    {
        $select = "SELECT COUNT(*) AS COUNT
                     FROM PARCERIA
                    WHERE NRPARCNEGOCIO  = :NRPARCNEGOCIO
                      AND NRORG          = :NRORG
                      AND CDTIPOPARCEIRO = :CDTIPOPARCEIRO";

        $params = array
        (
            "NRORG"          => $row["NRORG"],
            "NRPARCNEGOCIO"  => $row["NRPARCNEGOCIO"],
            "CDTIPOPARCEIRO" => "INTERLOCUTOR"
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $resultado = $std->fetchAll();
            return $resultado[0]["COUNT"];
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function existeRelacParc($row)
    {
        $select = "SELECT COUNT(*) AS COUNT
                     FROM RELACIONAPARC
                    WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                      AND NRORG           = :NRORG
                      AND NRTIPORELACIONA = :NRTIPORELACIONA
                      AND NRPARCNEGOCIO  IN (SELECT NRPARCNEGOCIO
                                               FROM CLIENTE
                                              WHERE CDCLIENTE = :CDCLIENTE
                                                AND NRORG     = :NRORG)";

        $params = array
        (
            "NRORG"           => $row["NRORG"],
            "NRTIPORELACIONA" => 25,
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "CDCLIENTE"       => $row["CDCLIENTE"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $result = $std->fetchAll();
            return $result[0]["COUNT"];
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function existeInteClie($row)
    {
        $select = "SELECT COUNT(*) AS COUNT
                     FROM INTECLIE
                    WHERE NRRELACIONAPARC IN
                          (SELECT NRRELACIONAPARC
                             FROM RELACIONAPARC
                            WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                              AND NRORG           = :NRORG
                              AND NRTIPORELACIONA = :NRTIPORELACIONA)
                      AND NRORG           = :NRORG
                      AND CDCLIENTE       = :CDCLIENTE";

        $params = array
        (
            "NRORG"           => $row["NRORG"],
            "NRTIPORELACIONA" => 25,
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "CDCLIENTE"       => $row["CDCLIENTE"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $result = $std->fetchAll();
            return $result[0]["COUNT"];
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function ativaRelacParc($row)
    {
        $update = "UPDATE RELACIONAPARC
                      SET IDATIVO         = :IDATIVO,
                          CDOPERULTATU    = :CDOPERULTATU,
                          NRORGULTATU     = :NRORGULTATU,
                          DTULTATU        = SYSDATE
                    WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                      AND NRORG           = :NRORG
                      AND NRTIPORELACIONA = :NRTIPORELACIONA
                      AND NRPARCNEGOCIO  IN (SELECT NRPARCNEGOCIO
                                               FROM CLIENTE
                                              WHERE CDCLIENTE = :CDCLIENTE
                                                AND NRORG     = :NRORG)";

        $params = array
        (
            "NRORG"           => $row["NRORG"],
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "NRORGULTATU"     => $row["NRORGULTATU"],
            "CDOPERULTATU"    => $row["CDOPERULTATU"],
            "IDATIVO"         => "S",
            "NRTIPORELACIONA" => 25,
            "CDCLIENTE"       => $row["CDCLIENTE"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }

    public function ativaInteClie($row)
    {
        $update = "UPDATE INTECLIE
                      SET IDATIVO         = :IDATIVO,
                          CDOPERULTATU    = :CDOPERULTATU,
                          NRORGULTATU     = :NRORGULTATU,
                          DTULTATU        = SYSDATE
                    WHERE NRRELACIONAPARC IN
                          (SELECT NRRELACIONAPARC
                             FROM RELACIONAPARC
                            WHERE NRPARCNEGRELAC  = :NRPARCNEGOCIO
                              AND NRORG           = :NRORG
                              AND NRTIPORELACIONA = :NRTIPORELACIONA)
                      AND NRORG           = :NRORG
                      AND CDCLIENTE       = :CDCLIENTE";

        $params = array
        (
            "NRORG"           => $row["NRORG"],
            "NRPARCNEGOCIO"   => $row["NRPARCNEGOCIO"],
            "NRORGULTATU"     => $row["NRORGULTATU"],
            "CDOPERULTATU"    => $row["CDOPERULTATU"],
            "IDATIVO"         => "S",
            "NRTIPORELACIONA" => 25,
            "CDCLIENTE"       => $row["CDCLIENTE"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            throw new \Exception($e->getMessage());
        };
    }
    
    public function replicaFiliais($row){
        $insert = "INSERT INTO FILIOPER
                              (CDOPERADOR, CDFILIAL, IDEXIBAVISO, DTULTATUFOPE, NRORG, DTINCLUSAO,
                               DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, NRORGFILIAL, IDATIVO)
                       VALUES (:CDOPERADOR, :CDFILIAL, :IDEXIBAVISO, SYSDATE, :NRORG, SYSDATE,
                               SYSDATE, :NRORG, :CDOPERINCLUSAO, :NRORG, :CDOPERINCLUSAO, :NRORG, :IDATIVO)";

        $params = array (
            
            "CDOPERADOR"      => $row["CDOPERADOR"],
            "CDFILIAL"        => $row["CDFILIAL"],
            "IDEXIBAVISO"     => 'S',
            "NRORG"           => $row["NRORG"],
            "CDOPERINCLUSAO"  => $row["CDOPERINCLUSAO"],
            "IDATIVO"         => 'S'
        );

        try{
            $std = $this->entityManager->getConnection()->prepare($insert);
            $std->execute($params);
        }catch(\Exception $e){
            throw new \Exception($e->getMessage());
        };   
    }
}
?>