<?php
namespace Teknisa\Model\Teknisa\Repositories;
use Doctrine\DBAL\Connection;

class OmProdutoElemento extends \Doctrine\ORM\EntityRepository {
    
    public function getElements($productId, $conditions = '') {
        $query = <<<SQL
        SELECT *
          FROM (SELECT OME.ID, OME.LABEL, OME.UNIQUE_ID, OME.NRPRODUTO_ID, OME.PARENT_ID, OME.NRORDEM,
                       OME.NREXTERNAL_PRODUCT_ID, SIS.CDSISTEMA, SIS.NMSISTEMA, OMEP.UNIQUE_ID AS PARENT_UNIQUE_ID,
                       DECODE(OME.PARENT_ID, NULL, 'G', 'M') AS TYPE, OME.IDELEMENTOPADRAO,
                       (SELECT RTRIM(XMLAGG(XMLELEMENT(E, ORG.NRORG, ',')
                                          .EXTRACT('//text()')
                                          ORDER BY ORG.NRORG
                                       ).GETCLOBVAL(), ','
                                ) AS NMORGANIZACAO
                          FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC OMO
                          JOIN ORGANIZACAO ORG ON ORG.NRORG = OMO.NRORG_ID
                         WHERE OMO.NRPRODUTO_ELEMENTO_ID = OME.ID) AS SPECIFIC_ORG,
                         (SELECT RTRIM(XMLAGG(XMLELEMENT(E, ORG.NRORG || ' - ' || ORG.NMORGANIZACAO, ' | ')
                                          .EXTRACT('//text()')
                                          ORDER BY ORG.NMORGANIZACAO
                                       ).GETCLOBVAL(), ' | '
                                ) AS NMORGANIZACAO
                          FROM OM_PRODUTO_ELEMENTO_ORG_ESPEC OMO
                          JOIN ORGANIZACAO ORG ON ORG.NRORG = OMO.NRORG_ID
                         WHERE OMO.NRPRODUTO_ELEMENTO_ID = OME.ID) AS SPECIFIC_ORG_LABEL,
                       OME.CDOPERINCLUSAO, OME.CDOPERULTATU, OME.DTINCLUSAO, OME.DTULTATU, 
                       OME.IDATIVO, OME.NRORGINCLUSAO, OME.NRORGULTATU, OME.NRORG
                  FROM OM_PRODUTO_ELEMENTO OME
             LEFT JOIN SISTEMA SIS ON SIS.CDSISTEMA = OME.CDSISTEMA
             LEFT JOIN OM_PRODUTO_ELEMENTO OMEP ON OMEP.ID = OME.PARENT_ID
                 WHERE OME.NRPRODUTO_ID = :productId
               )
    	 WHERE 1 = 1
    	       $conditions
      ORDER BY NRORDEM
SQL;
        $params = array(
            'productId' => $productId
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }
    
    public function getElementsToDelete($productId, $uniqueIdNewElements){
        $query = <<<SQL
		SELECT UNIQUE_ID, ID, NRPRODUTO_ID AS PROJECT_ID
	      FROM OM_PRODUTO_ELEMENTO
	     WHERE NRPRODUTO_ID = :productId
	       AND (UNIQUE_ID NOT IN (:uniqueIdNewElements))
SQL;
        $params = array(
            'uniqueIdNewElements' => $uniqueIdNewElements,
            'productId' => $productId
        );
        
        $paramTypes = array(
            'uniqueIdNewElements' => Connection::PARAM_STR_ARRAY,
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params, $paramTypes);
    }

    public function getProductElementsByExternalProductIdAndProductNrOrgId($externalProductId, $nrOrg){
        $query = <<<SQL
        SELECT OME.UNIQUE_ID
          FROM OM_PRODUTO OMP
    INNER JOIN OM_PRODUTO_ORG OPO          ON OPO.NRPRODUTO_ID = OMP.ID
    INNER JOIN OM_PRODUTO_ORG_ELEMENTO OPE ON OPE.NRPRODUTO_ORG_ID = OPO.ID
    INNER JOIN OM_PRODUTO_ELEMENTO OME     ON OME.ID = OPE.NRPRODUTO_ELEMENTO_ID
         WHERE OMP.NREXTERNAL_PRODUCT_ID = :EXTERNAL_PRODUCT_ID
           AND OPO.NRORG_ID = :NRORG
SQL;
        $params = array(
            'EXTERNAL_PRODUCT_ID' => $externalProductId,
            'NRORG' => $nrOrg
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getProductElementsByProductIdAndCdcliente($productId, $cdCliente) {
        $query = <<<SQL
        SELECT OP.NREXTERNAL_PRODUCT_ID, OP.ID, OP.LABEL, OP.PARENT_ID
          FROM CLIENTE C, ORGANIZACAO O, OM_PRODUTO_ORG OO, OM_PRODUTO_ORG_ELEMENTO OE, OM_PRODUTO_ELEMENTO OP
         WHERE C.CDCLIENTE = :CDCLIENTE
           AND O.NRPARCNEGOCIO = C.NRPARCNEGOCIO
           AND OO.NRORG_ID = O.NRORG
           AND OO.NRPRODUTO_ID = (SELECT MAX(ID) FROM OM_PRODUTO OD WHERE OD.NREXTERNAL_PRODUCT_ID = :PRODUCT_ID)
           AND OE.NRPRODUTO_ORG_ID = OO.ID
           AND OP.NRPRODUTO_ID = OO.NRPRODUTO_ID
           AND OP.ID = OE.NRPRODUTO_ELEMENTO_ID
SQL;
        $params = array(
            'PRODUCT_ID' => $productId,
            'CDCLIENTE'  => $cdCliente
        );

        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getProductsWithElementsByNrOrgId($nrOrg, $isPrimaryOrg = null) {
        $primaryOrgFilter = '';
        if($isPrimaryOrg) {
            $primaryOrgFilter = "AND OPO.IDPRODUTOEXCLUSIVO = 'N'";
        }
        $query = <<<SQL
                SELECT OMP.NREXTERNAL_PRODUCT_ID AS "productId",
                       AVE.ELEMENTS AS "elements",
                       EXE.ELEMENTS AS "expiredElements"
                  FROM OM_PRODUTO OMP,
                       (SELECT OMP.ID,
                               RTRIM(XMLAGG(XMLELEMENT(E, OME.UNIQUE_ID, ',')
                                              .EXTRACT('//text()')
                                              ORDER BY OME.UNIQUE_ID
                                           ).GetClobVal(), ','
                                    ) AS ELEMENTS
                          FROM OM_PRODUTO OMP
                    INNER JOIN OM_PRODUTO_ORG OPO          ON OPO.NRPRODUTO_ID = OMP.ID $primaryOrgFilter
                    INNER JOIN OM_PRODUTO_ORG_ELEMENTO OPE ON OPE.NRPRODUTO_ORG_ID = OPO.ID
                                                          AND (TRUNC(OPE.DTVALIDADE) >= TRUNC(SYSDATE) OR OPE.DTVALIDADE IS NULL)
                    INNER JOIN OM_PRODUTO_ELEMENTO OME     ON OME.ID = OPE.NRPRODUTO_ELEMENTO_ID
                         WHERE OPO.NRORG_ID = :NRORG
                      GROUP BY OMP.ID) AVE,
                       (SELECT OMP.ID,
                               RTRIM(XMLAGG(XMLELEMENT(E, OME.UNIQUE_ID, ',')
                                              .EXTRACT('//text()')
                                              ORDER BY OME.UNIQUE_ID
                                           ).GetClobVal(), ','
                                    ) AS ELEMENTS
                          FROM OM_PRODUTO OMP
                    INNER JOIN OM_PRODUTO_ORG OPO          ON OPO.NRPRODUTO_ID = OMP.ID $primaryOrgFilter
                    INNER JOIN OM_PRODUTO_ORG_ELEMENTO OPE ON OPE.NRPRODUTO_ORG_ID = OPO.ID
                                                          AND (TRUNC(OPE.DTVALIDADE) < TRUNC(SYSDATE) AND OPE.DTVALIDADE IS NOT NULL)
                    INNER JOIN OM_PRODUTO_ELEMENTO OME     ON OME.ID = OPE.NRPRODUTO_ELEMENTO_ID
                         WHERE OPO.NRORG_ID = :NRORG
                      GROUP BY OMP.ID) EXE
                 WHERE OMP.ID = AVE.ID
                   AND OMP.ID = EXE.ID(+)
SQL;
        $params = array( 'NRORG' => $nrOrg );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getSystemProductLine($idTpLinhaProduto, $conditions = ''){
        $query = <<<SQL
        SELECT *
          FROM (SELECT SI.SGSISTEMA, SI.CDSISTEMA, SI.NMSISTEMA, SI.IDTECNOSIST
                  FROM SISTEMA SI
                 WHERE SI.IDCOMERCIAL = 'S'
                   AND SI.IDTIPLINPSIST = :IDTPLINHAPRODUTO
               )
    	 WHERE 1 = 1
    	       $conditions
      ORDER BY NMSISTEMA
SQL;
        $params = array(
            'IDTPLINHAPRODUTO' => $idTpLinhaProduto
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getElementsRelatedSystemByProduct($productId, $smElementsFilter = '') {
        $query = <<<SQL
            SELECT ID, NRPRODUTO_ID, CDSISTEMA
              FROM OM_PRODUTO_ELEMENTO
             WHERE CDSISTEMA IS NOT NULL
               AND NRPRODUTO_ID = :NRPRODUTO_ID
                   $smElementsFilter
SQL;
        $params = array(
            'NRPRODUTO_ID' => $productId
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getProductDefaultElements($productId) {
        $query = <<<SQL
          SELECT ELEM.UNIQUE_ID AS ID, ELEM.LABEL
            FROM OM_PRODUTO_ELEMENTO ELEM
      START WITH ELEM.ID IN (SELECT OE.ID
                               FROM OM_PRODUTO_ELEMENTO OE
                               JOIN OM_PRODUTO OP ON OP.ID = OE.NRPRODUTO_ID
                              WHERE OE.IDELEMENTOPADRAO = 'S'
                                AND OE.NREXTERNAL_PRODUCT_ID = :PRODUCT_ID)
      CONNECT BY PRIOR ELEM.PARENT_ID = ELEM.ID
SQL;
        $params = array(
            'PRODUCT_ID' => $productId
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }
}