describe("ShowInDevToolsProperty", function() {

	var setTree = ShowInDevTools.setTree;
	var clear = ShowInDevTools.clear;
	var properties = ['__metadata', 'widgets', 'fields','actions'];
	var obj = {"widgets": "widget"};
	var fileObj = {"isFolder": true, "isFile": false};
	var arrayObjs = [{"isFolder": true, "isFile": false}, {}];
	var objName = "ObjectName";
	var propertyTest = "This is a new property";
	var testFunction = function(obj){
		obj.newProperty = propertyTest;
		return obj;
	};

	var objProperties = {
		"class" : "10 col-xs-offset-1",
		"events" : [],
		"icon": "question icon black",
		"id": "29208878616866963111386",
		"isVisible": true,
		"isVisibleForm": true,
		"isVisibleGrid": false,
		"label": "Esqueceu a senha?",
		"wrong": {},
		"widgets": {
			"fields": {},
			"labels": "test"
		}
	};

	beforeEach(function(){
		window.templateUrl = "../../dyman/templates/dyman/";
		window.metadataUrl = "/json_test/test";
		window.serviceUrl = "../backend/service/index.php";
		module('ZeedhiApp');
		obj = {"widgets": "widget"};
	});

	it("The setPropertyShowInDevTools should set showInDevTools in true.", function () {
		setPropertyShowInDevTools(obj);
		expect(obj.showInDevTools).toBe(true);
		obj.showInDevTools = false;
		setPropertyShowInDevTools(obj);
		expect(obj.showInDevTools).toBe(true);
	});

	it("The deletePropertyShowInDevTools should remove showInDevTools of object.", function () {
		setPropertyShowInDevTools(obj);
		expect(obj.showInDevTools).toBe(true);
		deletePropertyShowInDevTools(obj);
		expect(obj.showInDevTools).toBe(undefined);
		deletePropertyShowInDevTools(obj);
		expect(obj.showInDevTools).toBe(undefined);
	});

	it("The setTree should apply the applyFunctionToObject of setPropertyShowInDevTools in object.", function () {
		setTree(arrayObjs);
		expect(arrayObjs[0].showInDevTools).toBe(true);
		setTree(obj);
		expect(obj.showInDevTools).toBe(true);
	});

	it("The clear should apply the applyFunctionToObject of deletePropertyShowInDevTools in object.", function () {
		setTree(obj);
		expect(obj.showInDevTools).toBe(true);
		clear(obj);
		expect(obj.showInDevTools).toBe(undefined);
	});

	it("IsZeedhiObject should return a negative number if a object is a zeedhi component.", function () {
		expect(isZeedhiObject(properties[0])).toBe(-1);
		expect(isZeedhiObject(properties[1])).toBe(-2);
		expect(isZeedhiObject(properties[2])).toBe(-3);
		expect(isZeedhiObject(properties[3])).toBe(-4);
		expect(isZeedhiObject("something")).toBe(0);
	});

	it("IsDeveloperObject should return true if a object is a zeedhi component.", function () {
		expect(isDeveloperObject(fileObj, objName)).toBe(true);
		expect(isDeveloperObject("something", true)).toBe(false);
	});

	it("IsZeedhiOrDeveloperObject should return true if a object is a zeedhi or developer object.", function () {
		expect(isZeedhiOrDeveloperObject(fileObj, objName)).toBe(true);
		expect(isZeedhiOrDeveloperObject("something", true)).toBe(0);
	});

	it("GetProperties should return object keys if a object isn't a zeedhi component.", function () {
		var newObj = {
			"prop1" : "prop1",
			"prop2" : "prop2",
			"prop3" : "prop3",
			"prop4" : "prop4",
			"prop5" : "prop5",
			"prop6" : "prop6"
		};
		expect(getProperties(newObj).length).toBe(6);
	});

	it("GetProperties should return zeedhi properties if a object is a zeedhi component.", function () {
		var zhObj = {
			'__metadata' :" ", 
			'widgets' : " ",
			'fields' : " ",
			'actions': " ",
			'thisIsNotProperty': "123"
		};
		expect(getProperties(zhObj).length).toBe(4);
		expect(getProperties(fileObj).length).toBe(2);
		expect(getProperties(obj)[0]).toBe("widgets");
	});

	it("ApplyFunctionToObject should applied a function foreach object.", function () {
		expect(getProperties(objProperties).length).toBe(1);
		applyFunctionToObject(objProperties, testFunction);
		expect(getProperties(objProperties).length).toBe(1);
		expect(objProperties.newProperty).toBe(propertyTest);
	});
});
